==> temporal-sdk-1.27.1-sources.jar: io/temporal/nexus/WorkflowMethodMethodInvoker.java <==
/*
 * Copyright (C) 2022 Temporal Technologies, Inc. All Rights Reserved.
 *
 * Copyright (C) 2012-2016 Amazon.com, Inc. or its affiliates. All Rights Reserved.
 *
 * Modifications copyright (C) 2017 Uber Technologies, Inc.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this material except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *   http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package io.temporal.nexus;

import io.temporal.api.common.v1.WorkflowExecution;
import io.temporal.internal.client.NexusStartWorkflowRequest;
import io.temporal.internal.client.WorkflowClientInternal;
import io.temporal.internal.nexus.CurrentNexusOperationContext;
import io.temporal.internal.nexus.NexusOperationContextImpl;
import io.temporal.workflow.Functions;

class WorkflowMethodMethodInvoker implements WorkflowHandleInvoker {
  private Functions.Proc workflow;

  public WorkflowMethodMethodInvoker(Functions.Proc workflow) {
    this.workflow = workflow;
  }

  @Override
  public WorkflowExecution invoke(NexusStartWorkflowRequest request) {
    NexusOperationContextImpl nexusCtx = CurrentNexusOperationContext.get();
    return ((WorkflowClientInternal) nexusCtx.getWorkflowClient().getInternal())
        .startNexus(request, workflow);
  }
}

==> temporal-sdk-1.28.0-sources.jar: io/temporal/nexus/WorkflowMethodMethodInvoker.java <==
/*
 * Copyright (C) 2022 Temporal Technologies, Inc. All Rights Reserved.
 *
 * Copyright (C) 2012-2016 Amazon.com, Inc. or its affiliates. All Rights Reserved.
 *
 * Modifications copyright (C) 2017 Uber Technologies, Inc.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this material except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *   http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package io.temporal.nexus;

import io.temporal.api.common.v1.WorkflowExecution;
import io.temporal.internal.client.NexusStartWorkflowRequest;
import io.temporal.internal.client.WorkflowClientInternal;
import io.temporal.internal.nexus.CurrentNexusOperationContext;
import io.temporal.internal.nexus.InternalNexusOperationContext;
import io.temporal.workflow.Functions;

class WorkflowMethodMethodInvoker implements WorkflowHandleInvoker {
  private Functions.Proc workflow;

  public WorkflowMethodMethodInvoker(Functions.Proc workflow) {
    this.workflow = workflow;
  }

  @Override
  public WorkflowExecution invoke(NexusStartWorkflowRequest request) {
    InternalNexusOperationContext nexusCtx = CurrentNexusOperationContext.get();
    return ((WorkflowClientInternal) nexusCtx.getWorkflowClient().getInternal())
        .startNexus(request, workflow);
  }
}
